@@ -74,11 +74,25 @@ class LoginVerify(TemplateView):
         if not user:
             if settings.LOGIN_FAILED_TEMPLATE_NAME:
                 context = self.get_context_data(**kwargs)
+                # The below settings are left in for backward compatibility
                 context['ONE_TOKEN_PER_USER'] = settings.ONE_TOKEN_PER_USER
                 context['REQUIRE_SAME_BROWSER'] = settings.REQUIRE_SAME_BROWSER
                 context['REQUIRE_SAME_IP'] = settings.REQUIRE_SAME_IP
                 context['ALLOW_SUPERUSER_LOGIN'] = settings.ALLOW_SUPERUSER_LOGIN  # NOQA: E501
                 context['ALLOW_STAFF_LOGIN'] = settings.ALLOW_STAFF_LOGIN
+
+                try:
+                    magiclink = MagicLink.objects.get(token=token)
+                except MagicLink.DoesNotExist:
+                    error = 'A magic link with that token could not be found'
+                    context['login_error'] = error
+                    return self.render_to_response(context)
+
+                try:
+                    magiclink.validate(request, email)
+                except MagicLinkError as error:
+                    context['login_error'] = str(error)
+
                 return self.render_to_response(context)
             else:
                 raise Http404()
@@ -114,9 +128,9 @@ class Signup(TemplateView):
             'SignupFormFull',
         ]
         forms = __import__('magiclink.forms', fromlist=from_list)
-        Form = getattr(forms, form_name)
+        SignupForm = getattr(forms, form_name)
 
-        form = Form(request.POST)
+        form = SignupForm(request.POST)
         if not form.is_valid():
             context[form_name] = form
             return self.render_to_response(context)
